@@ -10,21 +10,21 @@ Sys.setenv(DUCKPLYR_FALLBACK_COLLECT = 0)
 options(conflicts.policy = list(warn = FALSE))
 
 ## ----attach-------------------------------------------------------------------
-library(conflicted)
-library(duckplyr)
-conflict_prefer("filter", "dplyr")
+# library(conflicted)
+# library(duckplyr)
+# conflict_prefer("filter", "dplyr")
 
 ## ----include = FALSE----------------------------------------------------------
-Sys.setenv(DUCKPLYR_FALLBACK_COLLECT = "")
-Sys.setenv(DUCKPLYR_FALLBACK_AUTOUPLOAD = "")
-fallback_purge()
+# Sys.setenv(DUCKPLYR_FALLBACK_COLLECT = "")
+# Sys.setenv(DUCKPLYR_FALLBACK_AUTOUPLOAD = "")
+# fallback_purge()
 
 ## -----------------------------------------------------------------------------
-Sys.setenv(DUCKPLYR_FALLBACK_INFO = TRUE)
-out <-
-  flights_df() |>
-  summarize(.by = origin, paste(dest, collapse = " "))
+# Sys.setenv(DUCKPLYR_FALLBACK_INFO = TRUE)
+# out <-
+#   flights_df() |>
+#   summarize(.by = origin, paste(dest, collapse = " "))
 
 ## ----echo = FALSE-------------------------------------------------------------
-duckplyr:::fallback_autoupload()
+# duckplyr:::fallback_autoupload()
 
